package sgc.portal.cs.cs0401.persistence;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;
import sgc.portal.base.util.EasyHashMap;
import sgc.portal.cs.cs0401.dto.CS04010001USearch;
import sgc.portal.cs.cs0401.model.CS04010001U;
import sgc.portal.cs.cs0401.model.CS04010002U;

import java.util.List;
import java.util.Map;

@Mapper
public interface CS04010001UMapper {
	
	//담당자별주간보고 조회
	EasyHashMap<String, Object> selectTcsWeekWorkList(CS04010001USearch search);
	List<EasyHashMap<String, Object>> selectTcsWeekWorkRptList1(CS04010001USearch search);
	List<EasyHashMap<String, Object>> selectTcsWeekWorkRptList2(CS04010001USearch search);
	List<EasyHashMap<String, Object>> selectTcsWeekWorkCommList(CS04010001USearch search);
	List<EasyHashMap<String, Object>> selectTcsWeekWorkCommList2(CS04010001USearch search);
	
	//담당자별주간보고 등록 변경 삭제
	int selectTcsWeekWorkCount(CS04010001U cS04010001U);
	String selectworkBasedateTo(CS04010001U cS04010001U);
	List<EasyHashMap<String, Object>> selectWeekAndNextWeekCountList(CS04010001U cS04010001U);

	void insertTcsWeekWork(CS04010001U cS04010001U);
	void updateTcsWeekWork(CS04010001U cS04010001U);
	void deleteTcsWeekWork(CS04010001U cS04010001U);
	
	void insertTcsWeekWorkRpt(CS04010002U cS04010002U);
	void updateTcsWeekWorkRpt(CS04010002U cS04010002U);
	void deleteTcsWeekWorkRpt(CS04010001U cS04010001U);
	
	//담당자별주간보고 전주복사
	void insertTcsWeekWork2(CS04010001U cS04010001U);
	void insertTcsWeekWorkRpt2(CS04010002U cS04010002U);
	List<EasyHashMap<String, Object>> selectCopyWeekCountList(CS04010001U cS04010001U);
	List<EasyHashMap<String, Object>> selectCopyNextWeekCountList(CS04010001U cS04010001U);
	
	List<EasyHashMap<String, Object>> selectCopyWeekCountList2(CS04010001U cS04010001U);
}
